@@ -54,6 +54,7 @@ sub execute {
     $self->create_docs();
     $self->create_watch();
     $self->create_gbp_conf() if $self->cfg->pkg_emacsen;
+    $self->create_salsa_ci_yml();
 
     return(0);
 }
@@ -65,7 +66,6 @@ sub create_control {
 
     $src->Source( $self->pkgname );
     $src->Section("editors");
-    $src->Priority("optional");
     $src->Standards_Version( $self->debstdversion );
     $src->Build_Depends->add( sprintf "debhelper-compat (= %s)", $self->cfg->dh );
     $src->Build_Depends->add( "dh-elpa" );
@@ -202,6 +202,20 @@ sub create_copyright {
     $fh->close;
 }
 
+sub create_salsa_ci_yml {
+    my $self = shift;
+
+    my $fh = $self->_file_w( $self->debian_file("salsa-ci.yml") );
+    my $res = <<"EOF";
+---
+include:
+  - https://salsa.debian.org/salsa-ci-team/pipeline/raw/master/recipes/debian.yml
+EOF
+
+    $fh->print($res);
+    $fh->close;
+}
+
 =head1 COPYRIGHT & LICENSE
 
 =over
